==> org.eclipse.cdt.lsp.source_2.0.0.202406041551.jar: org/eclipse/cdt/lsp/internal/editor/EditorPreferredOptions.java <==
/*******************************************************************************
 * Copyright (c) 2023 Contributors to the Eclipse Foundation.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   See git history
 *******************************************************************************/

package org.eclipse.cdt.lsp.internal.editor;

import java.util.Objects;

import org.eclipse.cdt.lsp.PreferredOptions;
import org.eclipse.cdt.lsp.editor.EditorMetadata;
import org.eclipse.cdt.lsp.editor.EditorOptions;
import org.eclipse.cdt.lsp.editor.LanguageServerEnable;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.preferences.IScopeContext;

public class EditorPreferredOptions extends PreferredOptions implements EditorOptions, LanguageServerEnable {
	private final EditorMetadata metadata;
	private final LanguageServerEnable enable;

	public EditorPreferredOptions(String qualifier, IScopeContext[] scopes, EditorMetadata metadata,
			LanguageServerEnable enable) {
		super(qualifier, scopes);
		this.metadata = Objects.requireNonNull(metadata);
		this.enable = enable;
	}

	@Override
	public boolean preferLspEditor() {
		return booleanValue(metadata.preferLspEditor());
	}

	@Override
	public boolean formatOnSave() {
		return booleanValue(metadata.formatOnSave());
	}

	@Override
	public boolean formatAllLines() {
		return booleanValue(metadata.formatAllLines());
	}

	@Override
	public boolean formatEditedLines() {
		return booleanValue(metadata.formatEditedLines());
	}

	@Override
	public boolean isEnabledFor(IProject project) {
		if (enable != null) {
			return enable.isEnabledFor(project);
		}
		return booleanValue(metadata.preferLspEditor());
	}

}

==> org.eclipse.cdt.lsp.source_3.0.100.202504091618.jar: org/eclipse/cdt/lsp/internal/editor/EditorPreferredOptions.java <==
/*******************************************************************************
 * Copyright (c) 2023, 2025 Contributors to the Eclipse Foundation.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   See git history
 *******************************************************************************/

package org.eclipse.cdt.lsp.internal.editor;

import org.eclipse.cdt.lsp.PreferredOptions;
import org.eclipse.cdt.lsp.editor.EditorMetadata;
import org.eclipse.cdt.lsp.editor.EditorOptions;
import org.eclipse.cdt.lsp.editor.LanguageServerEnable;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.preferences.IScopeContext;

public final class EditorPreferredOptions extends PreferredOptions implements EditorOptions, LanguageServerEnable {
	private final LanguageServerEnable enable;

	public EditorPreferredOptions(EditorMetadata metadata, String qualifier, IScopeContext[] scopes,
			LanguageServerEnable enable) {
		super(metadata, qualifier, scopes);
		this.enable = enable;
	}

	@Override
	public boolean preferLspEditor() {
		return booleanValue(EditorMetadata.Predefined.preferLspEditor);
	}

	@Override
	public boolean showTryLspBanner() {
		return booleanValue(EditorMetadata.Predefined.showTryLspBanner);
	}

	@Override
	public boolean formatOnSave() {
		return booleanValue(EditorMetadata.Predefined.formatOnSave);
	}

	@Override
	public boolean formatAllLines() {
		return booleanValue(EditorMetadata.Predefined.formatAllLines);
	}

	@Override
	public boolean formatEditedLines() {
		return booleanValue(EditorMetadata.Predefined.formatEditedLines);
	}

	@Override
	public boolean isEnabledFor(IProject project) {
		if (enable != null) {
			return enable.isEnabledFor(project);
		}
		return booleanValue(EditorMetadata.Predefined.preferLspEditor);
	}

}
